require File.expand_path("../spec_helper.rb", __FILE__)

describe "Envdgen" do
  before do
    `rm -rf spec/tmp`
    `mkdir -p spec/tmp`
    `echo "FOO=1" > spec/tmp/.env`
    `echo "BAR=" >> spec/tmp/.env`
    `echo "BAZ=\"foo\"" >> spec/tmp/.env`
  end

  after :all do
    `rm -rf spec/tmp`
  end

  describe ".gen" do
    it "should generate environment directory from given env file" do
      Envdgen.gen("spec/tmp/.env", "spec/tmp/envdir")
      File.read("spec/tmp/envdir/FOO").should == "1"
      File.read("spec/tmp/envdir/BAR").should == ""
      File.read("spec/tmp/envdir/BAZ").should == "foo"
    end

    describe "overwriting" do
      let(:force) do
        false
      end

      before do
        `echo "FOO=1" > spec/tmp/.env`
        Envdgen.gen("spec/tmp/.env", "spec/tmp/envdir")
        `echo "FOO=2" > spec/tmp/.env`
        Envdgen.gen("spec/tmp/.env", "spec/tmp/envdir", force)
      end

      context "when force flag not set" do
        it "should write nothing" do
          File.read("spec/tmp/envdir/FOO").should == "1"
        end
      end

      context "when force flag set" do
        let(:force) do
          true
        end

        it "should overwrite variable" do
          File.read("spec/tmp/envdir/FOO").should == "2"
        end
      end
    end
  end
end
